JSON Schema Validation
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: linaro_json.schema
    :members:


JSON Document Schema Construction
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: linaro_json.document
    :members:
